@@ -2,6 +2,7 @@ import gzip
 from hashlib import md5
 from io import BytesIO
 
+import requests
 from fastapi import FastAPI
 import uvicorn
 from fastapi.middleware.cors import CORSMiddleware
@@ -43,7 +44,8 @@ def it_streaming(i: ItemUrlFilter):
 
 
 def write_csv_header_to_gz(i):
-    df = pl.read_csv(i.lst_url[0])
+    r = requests.get(i.lst_url[0])
+    df = pl.read_csv(r.content)
     bytesio_gz = BytesIO()
     with gzip.open(bytesio_gz, 'wb') as f:
         f.write((','.join(df.columns) + '\n').encode('utf-8'))
